package com.mdd.admin.validate.system;

import com.mdd.common.validator.annotation.IntegerContains;
import com.mdd.common.validator.annotation.StringContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("系统菜单创建参数")
public class SystemMenuCreateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @ApiModelProperty(
      value = "上级ID",
      required = true
   )
   private @NotNull(
   message = "上级菜单不能为空"
) @DecimalMin(
   value = "0",
   message = "上级菜单值不能少于0"
) Integer pid;
   @StringContains(
      values = {"M", "C", "A"},
      message = "菜单类型不是合法值(M,C,A)"
   )
   @ApiModelProperty(
      value = "菜单类型",
      required = true
   )
   private @NotNull(
   message = "menuType参数缺失"
) String menuType;
   @ApiModelProperty(
      value = "菜单名称",
      required = true
   )
   private @NotNull(
   message = "缺少参数menuName"
) @Length(
   min = 1,
   max = 30,
   message = "菜单名称必须在1~30个字符内"
) String menuName;
   @ApiModelProperty("菜单图标")
   private @Length(
   max = 100,
   message = "图标名称不能超过100个字符"
) String menuIcon;
   @ApiModelProperty("菜单排序")
   private @NotNull(
   message = "排序号不能为空"
) @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer menuSort;
   @ApiModelProperty("权限字符")
   private @Length(
   max = 100,
   message = "权限字符不能超过100个字符"
) String perms;
   @ApiModelProperty("路由地址")
   private @Length(
   max = 200,
   message = "路由地址不能超过200个字符"
) String paths;
   @ApiModelProperty("前端组件")
   private @Length(
   max = 200,
   message = "前端组件不能超过200个字符"
) String component;
   @ApiModelProperty("选中菜单")
   private @Length(
   max = 200,
   message = "选中菜单路径不能超过200个字符"
) String selected;
   @ApiModelProperty("路由参数")
   private @Length(
   max = 200,
   message = "路由参数不能超过200个字符"
) String params;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "缓存状态",
      required = true
   )
   private @NotNull(
   message = "请选择缓存状态"
) Integer isCache;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "显示状态",
      required = true
   )
   private @NotNull(
   message = "请选择显示状态"
) Integer isShow;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "菜单状态",
      required = true
   )
   private @NotNull(
   message = "请选择菜单状态"
) Integer isDisable;

   public @NotNull(
   message = "上级菜单不能为空"
) Integer getPid() {
      return this.pid;
   }

   public @NotNull(
   message = "menuType参数缺失"
) String getMenuType() {
      return this.menuType;
   }

   public @NotNull(
   message = "缺少参数menuName"
) String getMenuName() {
      return this.menuName;
   }

   public String getMenuIcon() {
      return this.menuIcon;
   }

   public @NotNull(
   message = "排序号不能为空"
) Integer getMenuSort() {
      return this.menuSort;
   }

   public String getPerms() {
      return this.perms;
   }

   public String getPaths() {
      return this.paths;
   }

   public String getComponent() {
      return this.component;
   }

   public String getSelected() {
      return this.selected;
   }

   public String getParams() {
      return this.params;
   }

   public @NotNull(
   message = "请选择缓存状态"
) Integer getIsCache() {
      return this.isCache;
   }

   public @NotNull(
   message = "请选择显示状态"
) Integer getIsShow() {
      return this.isShow;
   }

   public @NotNull(
   message = "请选择菜单状态"
) Integer getIsDisable() {
      return this.isDisable;
   }

   public void setPid(@NotNull(
   message = "上级菜单不能为空"
) Integer pid) {
      this.pid = pid;
   }

   public void setMenuType(@NotNull(
   message = "menuType参数缺失"
) String menuType) {
      this.menuType = menuType;
   }

   public void setMenuName(@NotNull(
   message = "缺少参数menuName"
) String menuName) {
      this.menuName = menuName;
   }

   public void setMenuIcon(String menuIcon) {
      this.menuIcon = menuIcon;
   }

   public void setMenuSort(@NotNull(
   message = "排序号不能为空"
) Integer menuSort) {
      this.menuSort = menuSort;
   }

   public void setPerms(String perms) {
      this.perms = perms;
   }

   public void setPaths(String paths) {
      this.paths = paths;
   }

   public void setComponent(String component) {
      this.component = component;
   }

   public void setSelected(String selected) {
      this.selected = selected;
   }

   public void setParams(String params) {
      this.params = params;
   }

   public void setIsCache(@NotNull(
   message = "请选择缓存状态"
) Integer isCache) {
      this.isCache = isCache;
   }

   public void setIsShow(@NotNull(
   message = "请选择显示状态"
) Integer isShow) {
      this.isShow = isShow;
   }

   public void setIsDisable(@NotNull(
   message = "请选择菜单状态"
) Integer isDisable) {
      this.isDisable = isDisable;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof SystemMenuCreateValidate)) {
         return false;
      } else {
         SystemMenuCreateValidate other = (SystemMenuCreateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label167: {
               Object this$pid = this.getPid();
               Object other$pid = other.getPid();
               if (this$pid == null) {
                  if (other$pid == null) {
                     break label167;
                  }
               } else if (this$pid.equals(other$pid)) {
                  break label167;
               }

               return false;
            }

            Object this$menuSort = this.getMenuSort();
            Object other$menuSort = other.getMenuSort();
            if (this$menuSort == null) {
               if (other$menuSort != null) {
                  return false;
               }
            } else if (!this$menuSort.equals(other$menuSort)) {
               return false;
            }

            label153: {
               Object this$isCache = this.getIsCache();
               Object other$isCache = other.getIsCache();
               if (this$isCache == null) {
                  if (other$isCache == null) {
                     break label153;
                  }
               } else if (this$isCache.equals(other$isCache)) {
                  break label153;
               }

               return false;
            }

            Object this$isShow = this.getIsShow();
            Object other$isShow = other.getIsShow();
            if (this$isShow == null) {
               if (other$isShow != null) {
                  return false;
               }
            } else if (!this$isShow.equals(other$isShow)) {
               return false;
            }

            label139: {
               Object this$isDisable = this.getIsDisable();
               Object other$isDisable = other.getIsDisable();
               if (this$isDisable == null) {
                  if (other$isDisable == null) {
                     break label139;
                  }
               } else if (this$isDisable.equals(other$isDisable)) {
                  break label139;
               }

               return false;
            }

            Object this$menuType = this.getMenuType();
            Object other$menuType = other.getMenuType();
            if (this$menuType == null) {
               if (other$menuType != null) {
                  return false;
               }
            } else if (!this$menuType.equals(other$menuType)) {
               return false;
            }

            label125: {
               Object this$menuName = this.getMenuName();
               Object other$menuName = other.getMenuName();
               if (this$menuName == null) {
                  if (other$menuName == null) {
                     break label125;
                  }
               } else if (this$menuName.equals(other$menuName)) {
                  break label125;
               }

               return false;
            }

            label118: {
               Object this$menuIcon = this.getMenuIcon();
               Object other$menuIcon = other.getMenuIcon();
               if (this$menuIcon == null) {
                  if (other$menuIcon == null) {
                     break label118;
                  }
               } else if (this$menuIcon.equals(other$menuIcon)) {
                  break label118;
               }

               return false;
            }

            Object this$perms = this.getPerms();
            Object other$perms = other.getPerms();
            if (this$perms == null) {
               if (other$perms != null) {
                  return false;
               }
            } else if (!this$perms.equals(other$perms)) {
               return false;
            }

            label104: {
               Object this$paths = this.getPaths();
               Object other$paths = other.getPaths();
               if (this$paths == null) {
                  if (other$paths == null) {
                     break label104;
                  }
               } else if (this$paths.equals(other$paths)) {
                  break label104;
               }

               return false;
            }

            label97: {
               Object this$component = this.getComponent();
               Object other$component = other.getComponent();
               if (this$component == null) {
                  if (other$component == null) {
                     break label97;
                  }
               } else if (this$component.equals(other$component)) {
                  break label97;
               }

               return false;
            }

            Object this$selected = this.getSelected();
            Object other$selected = other.getSelected();
            if (this$selected == null) {
               if (other$selected != null) {
                  return false;
               }
            } else if (!this$selected.equals(other$selected)) {
               return false;
            }

            Object this$params = this.getParams();
            Object other$params = other.getParams();
            if (this$params == null) {
               if (other$params != null) {
                  return false;
               }
            } else if (!this$params.equals(other$params)) {
               return false;
            }

            return true;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof SystemMenuCreateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $pid = this.getPid();
      result = result * 59 + ($pid == null ? 43 : $pid.hashCode());
      Object $menuSort = this.getMenuSort();
      result = result * 59 + ($menuSort == null ? 43 : $menuSort.hashCode());
      Object $isCache = this.getIsCache();
      result = result * 59 + ($isCache == null ? 43 : $isCache.hashCode());
      Object $isShow = this.getIsShow();
      result = result * 59 + ($isShow == null ? 43 : $isShow.hashCode());
      Object $isDisable = this.getIsDisable();
      result = result * 59 + ($isDisable == null ? 43 : $isDisable.hashCode());
      Object $menuType = this.getMenuType();
      result = result * 59 + ($menuType == null ? 43 : $menuType.hashCode());
      Object $menuName = this.getMenuName();
      result = result * 59 + ($menuName == null ? 43 : $menuName.hashCode());
      Object $menuIcon = this.getMenuIcon();
      result = result * 59 + ($menuIcon == null ? 43 : $menuIcon.hashCode());
      Object $perms = this.getPerms();
      result = result * 59 + ($perms == null ? 43 : $perms.hashCode());
      Object $paths = this.getPaths();
      result = result * 59 + ($paths == null ? 43 : $paths.hashCode());
      Object $component = this.getComponent();
      result = result * 59 + ($component == null ? 43 : $component.hashCode());
      Object $selected = this.getSelected();
      result = result * 59 + ($selected == null ? 43 : $selected.hashCode());
      Object $params = this.getParams();
      result = result * 59 + ($params == null ? 43 : $params.hashCode());
      return result;
   }

   public String toString() {
      return "SystemMenuCreateValidate(pid=" + this.getPid() + ", menuType=" + this.getMenuType() + ", menuName=" + this.getMenuName() + ", menuIcon=" + this.getMenuIcon() + ", menuSort=" + this.getMenuSort() + ", perms=" + this.getPerms() + ", paths=" + this.getPaths() + ", component=" + this.getComponent() + ", selected=" + this.getSelected() + ", params=" + this.getParams() + ", isCache=" + this.getIsCache() + ", isShow=" + this.getIsShow() + ", isDisable=" + this.getIsDisable() + ")";
   }
}
